@@ -23,36 +23,34 @@
 #include "migrationscheduler.h"
 #include <QVBoxLayout>
 #include <QTreeView>
-#include <QStandardItemModel>
 #include <QAction>
 #include <QListView>
-#include <QApplication>
 #include <QLabel>
 #include <KToolBar>
-#include <KDebug>
-#include <KIcon>
-#include <KDialog>
+#include <QIcon>
+#include <QDialog>
 #include <KLocalizedString>
+#include <QDialogButtonBox>
 
 MigrationStatusWidget::MigrationStatusWidget(MigrationScheduler &scheduler, QWidget *parent)
-    :QWidget(parent),
-    mScheduler(scheduler)
+    : QWidget(parent),
+      mScheduler(scheduler)
 {
     QVBoxLayout *vboxLayout = new QVBoxLayout;
     {
         KToolBar *toolbar = new KToolBar(QLatin1String("MigrationControlToolbar"), this);
 
         QAction *start = toolbar->addAction(QLatin1String("Start"));
-        start->setIcon(KIcon(QLatin1String("media-playback-start")));
-        connect(start, SIGNAL(triggered(bool)), this, SLOT(startSelected()));
+        start->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
+        connect(start, &QAction::triggered, this, &MigrationStatusWidget::startSelected);
 
         QAction *pause = toolbar->addAction(QLatin1String("Pause"));
-        pause->setIcon(KIcon(QLatin1String("media-playback-pause")));
-        connect(pause, SIGNAL(triggered(bool)), this, SLOT(pauseSelected()));
+        pause->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-pause")));
+        connect(pause, &QAction::triggered, this, &MigrationStatusWidget::pauseSelected);
 
         QAction *abort = toolbar->addAction(QLatin1String("Abort"));
-        abort->setIcon(KIcon(QLatin1String("media-playback-stop")));
-        connect(abort, SIGNAL(triggered(bool)), this, SLOT(abortSelected()));
+        abort->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-stop")));
+        connect(abort, &QAction::triggered, this, &MigrationStatusWidget::abortSelected);
 
         vboxLayout->addWidget(toolbar);
     }
@@ -63,7 +61,7 @@ MigrationStatusWidget::MigrationStatusWidget(MigrationScheduler &scheduler, QWid
         Q_ASSERT(mSelectionModel);
         //Not sure why this is required, but otherwise the view doesn't load anything from the model
         treeView->update(QModelIndex());
-        connect(treeView, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onItemActivated(QModelIndex)));
+        connect(treeView, &QTreeView::doubleClicked, this, &MigrationStatusWidget::onItemActivated);
 
         vboxLayout->addWidget(treeView);
     }
@@ -93,8 +91,15 @@ void MigrationStatusWidget::abortSelected()
 
 void MigrationStatusWidget::onItemActivated(const QModelIndex &index)
 {
-    KDialog *dlg = new KDialog(this);
+    QDialog *dlg = new QDialog(this);
+    QVBoxLayout *topLayout = new QVBoxLayout;
+    dlg->setLayout(topLayout);
     QWidget *widget = new QWidget(dlg);
+    topLayout->addWidget(widget);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    connect(buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
+    topLayout->addWidget(buttonBox);
 
     QVBoxLayout *vboxLayout = new QVBoxLayout;
     {
@@ -106,20 +111,17 @@ void MigrationStatusWidget::onItemActivated(const QModelIndex &index)
     }
     {
         QHBoxLayout *hboxLayout = new QHBoxLayout;
-        QLabel *label = new QLabel(QString::fromLatin1("<a href=\"%1\">%2</a>").arg(index.data(MigratorModel::LogfileRole).toString()).arg(ki18n("Logfile").toString()), widget);
+        QLabel *label = new QLabel(QStringLiteral("<a href=\"%1\">%2</a>").arg(index.data(MigratorModel::LogfileRole).toString()).arg(ki18n("Logfile").toString()), widget);
         label->setOpenExternalLinks(true);
         hboxLayout->addWidget(label);
         hboxLayout->addStretch();
         vboxLayout->addLayout(hboxLayout);
     }
     widget->setLayout(vboxLayout);
-    dlg->setMainWidget(widget);
 
     dlg->setAttribute(Qt::WA_DeleteOnClose);
-    dlg->setCaption(i18nc("Title of the window displaying the log of a single migration job.", "Migration Info"));
-    dlg->setButtons(KDialog::Close);
+    dlg->setWindowTitle(i18nc("Title of the window displaying the log of a single migration job.", "Migration Info"));
     dlg->resize(600, 300);
     dlg->show();
 }
 
-
