@@ -18,24 +18,23 @@
 */
 
 #include "newmailnotifierselectcollectionwidget.h"
-#include "newmailnotifierattribute.h"
+#include <AkonadiCore/NewMailNotifierAttribute>
 
-
-#include <Akonadi/CollectionModifyJob>
-#include <Akonadi/CollectionFilterProxyModel>
+#include <CollectionModifyJob>
+#include <CollectionFilterProxyModel>
 #include <KRecursiveFilterProxyModel>
 
-#include <Akonadi/ChangeRecorder>
-#include <Akonadi/EntityTreeModel>
-#include <Akonadi/Collection>
+#include <ChangeRecorder>
+#include <EntityTreeModel>
+#include <Collection>
 #include <KMime/Message>
 
 #include <KCheckableProxyModel>
 
 #include <KLocalizedString>
-#include <KPushButton>
+#include <QPushButton>
 #include <KLineEdit>
-#include <KDebug>
+#include "newmailnotifier_debug.h"
 
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -53,39 +52,37 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     vbox->addWidget(label);
 
     // Create a new change recorder.
-    mChangeRecorder = new Akonadi::ChangeRecorder( this );
-    mChangeRecorder->setMimeTypeMonitored( KMime::Message::mimeType() );
-    mChangeRecorder->fetchCollection( true );
-    mChangeRecorder->setAllMonitored( true );
+    mChangeRecorder = new Akonadi::ChangeRecorder(this);
+    mChangeRecorder->setMimeTypeMonitored(KMime::Message::mimeType());
+    mChangeRecorder->fetchCollection(true);
+    mChangeRecorder->setAllMonitored(true);
 
-    mModel = new Akonadi::EntityTreeModel( mChangeRecorder, this );
+    mModel = new Akonadi::EntityTreeModel(mChangeRecorder, this);
     // Set the model to show only collections, not items.
-    mModel->setItemPopulationStrategy( Akonadi::EntityTreeModel::NoItemPopulation );
-    connect(mModel, SIGNAL(collectionTreeFetched(Akonadi::Collection::List)), SLOT(slotCollectionTreeFetched()));
+    mModel->setItemPopulationStrategy(Akonadi::EntityTreeModel::NoItemPopulation);
+    connect(mModel, &Akonadi::EntityTreeModel::collectionTreeFetched, this, &NewMailNotifierSelectCollectionWidget::slotCollectionTreeFetched);
 
-    Akonadi::CollectionFilterProxyModel *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel( this );
-    mimeTypeProxy->setExcludeVirtualCollections( true );
-    mimeTypeProxy->addMimeTypeFilters( QStringList() << KMime::Message::mimeType() );
-    mimeTypeProxy->setSourceModel( mModel );
+    Akonadi::CollectionFilterProxyModel *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
+    mimeTypeProxy->setExcludeVirtualCollections(true);
+    mimeTypeProxy->addMimeTypeFilters(QStringList() << KMime::Message::mimeType());
+    mimeTypeProxy->setSourceModel(mModel);
 
     // Create the Check proxy model.
-    mSelectionModel = new QItemSelectionModel( mimeTypeProxy );
-    mCheckProxy = new KCheckableProxyModel( this );
-    mCheckProxy->setSelectionModel( mSelectionModel );
-    mCheckProxy->setSourceModel( mimeTypeProxy );
-
+    mSelectionModel = new QItemSelectionModel(mimeTypeProxy);
+    mCheckProxy = new KCheckableProxyModel(this);
+    mCheckProxy->setSelectionModel(mSelectionModel);
+    mCheckProxy->setSourceModel(mimeTypeProxy);
 
     mCollectionFilter = new KRecursiveFilterProxyModel(this);
     mCollectionFilter->setSourceModel(mCheckProxy);
     mCollectionFilter->setDynamicSortFilter(true);
     mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
-
     KLineEdit *searchLine = new KLineEdit(this);
     searchLine->setPlaceholderText(i18n("Search..."));
     searchLine->setClearButtonShown(true);
-    connect(searchLine, SIGNAL(textChanged(QString)),
-            this, SLOT(slotSetCollectionFilter(QString)));
+    connect(searchLine, &QLineEdit::textChanged,
+            this, &NewMailNotifierSelectCollectionWidget::slotSetCollectionFilter);
 
     vbox->addWidget(searchLine);
 
@@ -94,17 +91,17 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     mFolderView->setAlternatingRowColors(true);
     vbox->addWidget(mFolderView);
 
-    mFolderView->setModel( mCollectionFilter );
+    mFolderView->setModel(mCollectionFilter);
 
     QHBoxLayout *hbox = new QHBoxLayout;
     vbox->addLayout(hbox);
 
-    KPushButton *button = new KPushButton(i18n("&Select All"), this);
-    connect(button, SIGNAL(clicked(bool)), this, SLOT(slotSelectAllCollections()));
+    QPushButton *button = new QPushButton(i18n("&Select All"), this);
+    connect(button, &QPushButton::clicked, this, &NewMailNotifierSelectCollectionWidget::slotSelectAllCollections);
     hbox->addWidget(button);
 
-    button = new KPushButton(i18n("&Unselect All"), this);
-    connect(button, SIGNAL(clicked(bool)), this, SLOT(slotUnselectAllCollections()));
+    button = new QPushButton(i18n("&Unselect All"), this);
+    connect(button, &QPushButton::clicked, this, &NewMailNotifierSelectCollectionWidget::slotUnselectAllCollections);
     hbox->addWidget(button);
     hbox->addStretch(1);
     setLayout(vbox);
@@ -147,76 +144,75 @@ void NewMailNotifierSelectCollectionWidget::slotUnselectAllCollections()
 
 void NewMailNotifierSelectCollectionWidget::updateStatus(const QModelIndex &parent)
 {
-    const int nbCol = mCheckProxy->rowCount( parent );
-    for ( int i = 0; i < nbCol; ++i ) {
-        const QModelIndex child = mCheckProxy->index( i, 0, parent );
+    const int nbCol = mCheckProxy->rowCount(parent);
+    for (int i = 0; i < nbCol; ++i) {
+        const QModelIndex child = mCheckProxy->index(i, 0, parent);
 
         const Akonadi::Collection collection =
-                mCheckProxy->data( child, Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+            mCheckProxy->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
-        NewMailNotifierAttribute *attr = collection.attribute<NewMailNotifierAttribute>();
+        Akonadi::NewMailNotifierAttribute *attr = collection.attribute<Akonadi::NewMailNotifierAttribute>();
         if (!attr || !attr->ignoreNewMail()) {
-            mCheckProxy->setData( child, Qt::Checked, Qt::CheckStateRole );
+            mCheckProxy->setData(child, Qt::Checked, Qt::CheckStateRole);
         }
-        updateStatus( child );
+        updateStatus(child);
     }
     mNeedUpdate = false;
 }
 
 void NewMailNotifierSelectCollectionWidget::forceStatus(const QModelIndex &parent, bool status)
 {
-    const int nbCol = mCheckProxy->rowCount( parent );
-    for ( int i = 0; i < nbCol; ++i ) {
-        const QModelIndex child = mCheckProxy->index( i, 0, parent );
-        mCheckProxy->setData( child, status ? Qt::Checked : Qt::Unchecked, Qt::CheckStateRole );
-        forceStatus( child, status );
+    const int nbCol = mCheckProxy->rowCount(parent);
+    for (int i = 0; i < nbCol; ++i) {
+        const QModelIndex child = mCheckProxy->index(i, 0, parent);
+        mCheckProxy->setData(child, status ? Qt::Checked : Qt::Unchecked, Qt::CheckStateRole);
+        forceStatus(child, status);
     }
 }
 
 void NewMailNotifierSelectCollectionWidget::updateCollectionsRecursive(const QModelIndex &parent)
 {
-    const int nbCol = mCheckProxy->rowCount( parent );
-    for ( int i = 0; i < nbCol; ++i ) {
-        const QModelIndex child = mCheckProxy->index( i, 0, parent );
+    const int nbCol = mCheckProxy->rowCount(parent);
+    for (int i = 0; i < nbCol; ++i) {
+        const QModelIndex child = mCheckProxy->index(i, 0, parent);
 
         Akonadi::Collection collection =
-                mCheckProxy->data( child, Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+            mCheckProxy->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
-        NewMailNotifierAttribute *attr = collection.attribute<NewMailNotifierAttribute>();
-        Akonadi::CollectionModifyJob *modifyJob = 0;
-        const bool selected = (mCheckProxy->data( child, Qt::CheckStateRole ).value<int>() != 0);
+        Akonadi::NewMailNotifierAttribute *attr = collection.attribute<Akonadi::NewMailNotifierAttribute>();
+        Akonadi::CollectionModifyJob *modifyJob = Q_NULLPTR;
+        const bool selected = (mCheckProxy->data(child, Qt::CheckStateRole).value<int>() != 0);
         if (selected && attr && attr->ignoreNewMail()) {
-            collection.removeAttribute<NewMailNotifierAttribute>();
+            collection.removeAttribute<Akonadi::NewMailNotifierAttribute>();
             modifyJob = new Akonadi::CollectionModifyJob(collection);
             modifyJob->setProperty("AttributeAdded", true);
         } else if (!selected && (!attr || !attr->ignoreNewMail())) {
-            attr = collection.attribute<NewMailNotifierAttribute>(Akonadi::Entity::AddIfMissing);
+            attr = collection.attribute<Akonadi::NewMailNotifierAttribute>(Akonadi::Entity::AddIfMissing);
             attr->setIgnoreNewMail(true);
             modifyJob = new Akonadi::CollectionModifyJob(collection);
             modifyJob->setProperty("AttributeAdded", false);
         }
 
         if (modifyJob) {
-            connect(modifyJob, SIGNAL(finished(KJob*)), SLOT(slotModifyJobDone(KJob*)));
+            connect(modifyJob, &Akonadi::CollectionModifyJob::finished, this, &NewMailNotifierSelectCollectionWidget::slotModifyJobDone);
         }
         updateCollectionsRecursive(child);
     }
 }
 
-void NewMailNotifierSelectCollectionWidget::slotModifyJobDone(KJob* job)
+void NewMailNotifierSelectCollectionWidget::slotModifyJobDone(KJob *job)
 {
-    Akonadi::CollectionModifyJob *modifyJob = qobject_cast<Akonadi::CollectionModifyJob*>(job);
+    Akonadi::CollectionModifyJob *modifyJob = qobject_cast<Akonadi::CollectionModifyJob *>(job);
     if (modifyJob && job->error()) {
         if (job->property("AttributeAdded").toBool()) {
-            kWarning() << "Failed to append NewMailNotifierAttribute to collection"
-                       << modifyJob->collection().id() << ":"
-                       << job->errorString();
+            qCWarning(NEWMAILNOTIFIER_LOG) << "Failed to append NewMailNotifierAttribute to collection"
+                                           << modifyJob->collection().id() << ":"
+                                           << job->errorString();
         } else {
-            kWarning() << "Failed to remove NewMailNotifierAttribute from collection"
-                       << modifyJob->collection().id() << ":"
-                       << job->errorString();
+            qCWarning(NEWMAILNOTIFIER_LOG) << "Failed to remove NewMailNotifierAttribute from collection"
+                                           << modifyJob->collection().id() << ":"
+                                           << job->errorString();
         }
     }
 }
 
-
