@@ -20,21 +20,22 @@
 #include "newmailnotifieragentsettings.h"
 
 #include <Akonadi/Contact/ContactSearchJob>
-#include <Akonadi/ItemFetchJob>
-#include <Akonadi/ItemFetchScope>
-#include <akonadi/kmime/messageparts.h>
+#include <ItemFetchJob>
+#include <ItemFetchScope>
+#include <Akonadi/KMime/MessageParts>
 
 #include <KNotification>
-#include <KPIMUtils/Email>
+#include <KEmailAddress>
 
 #include <KMime/Message>
 
 #include <KLocalizedString>
+#include "newmailnotifier_debug.h"
 
 #include <QTextDocument>
-#include <QDBusConnection>
-#include <QDBusInterface>
-#include <QDBusConnectionInterface>
+#ifdef HAVE_SPEECH
+#include <QTextToSpeech>
+#endif
 
 SpecialNotifierJob::SpecialNotifierJob(const QStringList &listEmails, const QString &path, Akonadi::Item::Id id, QObject *parent)
     : QObject(parent),
@@ -43,10 +44,10 @@ SpecialNotifierJob::SpecialNotifierJob(const QStringList &listEmails, const QStr
       mItemId(id)
 {
     Akonadi::Item item(mItemId);
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( item, this );
-    job->fetchScope().fetchPayloadPart( Akonadi::MessagePart::Envelope, true );
+    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    job->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Envelope, true);
 
-    connect( job, SIGNAL(result(KJob*)), SLOT(slotItemFetchJobDone(KJob*)) );
+    connect(job, &Akonadi::ItemFetchJob::result, this, &SpecialNotifierJob::slotItemFetchJobDone);
 }
 
 SpecialNotifierJob::~SpecialNotifierJob()
@@ -61,17 +62,17 @@ void SpecialNotifierJob::setDefaultPixmap(const QPixmap &pixmap)
 
 void SpecialNotifierJob::slotItemFetchJobDone(KJob *job)
 {
-    if ( job->error() ) {
-        kWarning() << job->errorString();
+    if (job->error()) {
+        qCWarning(NEWMAILNOTIFIER_LOG) << job->errorString();
         deleteLater();
         return;
     }
 
-    const Akonadi::Item::List lst = qobject_cast<Akonadi::ItemFetchJob*>( job )->items();
+    const Akonadi::Item::List lst = qobject_cast<Akonadi::ItemFetchJob *>(job)->items();
     if (lst.count() == 1) {
         const Akonadi::Item item = lst.first();
-        if ( !item.hasPayload<KMime::Message::Ptr>() ) {
-            kDebug()<<" message has not payload.";
+        if (!item.hasPayload<KMime::Message::Ptr>()) {
+            qCDebug(NEWMAILNOTIFIER_LOG) << " message has not payload.";
             deleteLater();
             return;
         }
@@ -80,32 +81,32 @@ void SpecialNotifierJob::slotItemFetchJobDone(KJob *job)
         mFrom = mb->from()->asUnicodeString();
         mSubject = mb->subject()->asUnicodeString();
         if (NewMailNotifierAgentSettings::showPhoto()) {
-            Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob( this );
-            job->setLimit( 1 );
-            job->setQuery( Akonadi::ContactSearchJob::Email, KPIMUtils::firstEmailAddress(mFrom).toLower(), Akonadi::ContactSearchJob::ExactMatch );
-            connect( job, SIGNAL(result(KJob*)), SLOT(slotSearchJobFinished(KJob*)) );
+            Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob(this);
+            job->setLimit(1);
+            job->setQuery(Akonadi::ContactSearchJob::Email, KEmailAddress::firstEmailAddress(mFrom).toLower(), Akonadi::ContactSearchJob::ExactMatch);
+            connect(job, &Akonadi::ItemFetchJob::result, this, &SpecialNotifierJob::slotSearchJobFinished);
         } else {
             emitNotification(mDefaultPixmap);
             deleteLater();
         }
     } else {
-        kWarning()<<" Found item different from 1: "<<lst.count();
+        qCWarning(NEWMAILNOTIFIER_LOG) << " Found item different from 1: " << lst.count();
         deleteLater();
         return;
     }
 }
 
-void SpecialNotifierJob::slotSearchJobFinished( KJob *job )
+void SpecialNotifierJob::slotSearchJobFinished(KJob *job)
 {
-    const Akonadi::ContactSearchJob *searchJob = qobject_cast<Akonadi::ContactSearchJob*>( job );
-    if ( searchJob->error() ) {
-        kWarning() << "Unable to fetch contact:" << searchJob->errorText();
+    const Akonadi::ContactSearchJob *searchJob = qobject_cast<Akonadi::ContactSearchJob *>(job);
+    if (searchJob->error()) {
+        qCWarning(NEWMAILNOTIFIER_LOG) << "Unable to fetch contact:" << searchJob->errorText();
         emitNotification(mDefaultPixmap);
         return;
     }
     if (!searchJob->contacts().isEmpty()) {
-        const KABC::Addressee addressee = searchJob->contacts().first();
-        const KABC::Picture photo = addressee.photo();
+        const KContacts::Addressee addressee = searchJob->contacts().at(0);
+        const KContacts::Picture photo = addressee.photo();
         const QImage image = photo.data();
         if (image.isNull()) {
             emitNotification(mDefaultPixmap);
@@ -120,7 +121,7 @@ void SpecialNotifierJob::slotSearchJobFinished( KJob *job )
 void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
 {
     if (NewMailNotifierAgentSettings::excludeEmailsFromMe()) {
-        Q_FOREACH( const QString &email, mListEmails) {
+        Q_FOREACH (const QString &email, mListEmails) {
             if (mFrom.contains(email)) {
                 //Exclude this notification
                 deleteLater();
@@ -131,15 +132,15 @@ void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
 
     QStringList result;
     if (NewMailNotifierAgentSettings::showFrom()) {
-        result << i18n("From: %1", Qt::escape(mFrom));
+        result << i18n("From: %1", mFrom.toHtmlEscaped());
     }
     if (NewMailNotifierAgentSettings::showSubject()) {
         QString subject = mSubject.simplified();
-        if (subject.length()> 80) {
+        if (subject.length() > 80) {
             subject.truncate(80);
-            subject += QLatin1String("...");
+            subject += QStringLiteral("...");
         }
-        result << i18n("Subject: %1", Qt::escape(subject));
+        result << i18n("Subject: %1", subject.toHtmlEscaped());
     }
     if (NewMailNotifierAgentSettings::showFolder()) {
         result << i18n("In: %1", mPath);
@@ -147,31 +148,31 @@ void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
 
     if (NewMailNotifierAgentSettings::textToSpeakEnabled()) {
         if (!NewMailNotifierAgentSettings::textToSpeak().isEmpty()) {
-            if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.kttsd"))) {
-                QDBusInterface ktts(QLatin1String("org.kde.kttsd"), QLatin1String("/KSpeech"), QLatin1String("org.kde.KSpeech"));
-                QString message = NewMailNotifierAgentSettings::textToSpeak();
-                message.replace(QLatin1String("%s"), Qt::escape(mSubject));
-                message.replace(QLatin1String("%f"), Qt::escape(mFrom));
-                ktts.asyncCall(QLatin1String("say"), message, 0);
-            }
+#ifdef HAVE_SPEECH
+            QTextToSpeech *speech = new QTextToSpeech(this);
+            QString message = NewMailNotifierAgentSettings::textToSpeak();
+            message.replace(QStringLiteral("%s"), mSubject.toHtmlEscaped());
+            message.replace(QStringLiteral("%f"), mFrom.toHtmlEscaped());
+            speech->say(message);
+#endif
         }
     }
 
     if (NewMailNotifierAgentSettings::showButtonToDisplayMail()) {
-        KNotification *notification= new KNotification ( QLatin1String("new-email"), 0, KNotification::CloseOnTimeout);
-        notification->setText( result.join(QLatin1String("\n")) );
-        notification->setPixmap( pixmap );
-        notification->setActions( QStringList() << i18n( "Show mail..." ) );
+        KNotification *notification = new KNotification(QStringLiteral("new-email"), Q_NULLPTR, KNotification::CloseOnTimeout);
+        notification->setText(result.join(QStringLiteral("\n")));
+        notification->setPixmap(pixmap);
+        notification->setActions(QStringList() << i18n("Show mail..."));
 
-        connect(notification, SIGNAL(activated(uint)), this, SLOT(slotOpenMail()) );
-        connect(notification, SIGNAL(closed()), this, SLOT(deleteLater()));
+        connect(notification, static_cast<void (KNotification::*)(unsigned int)>(&KNotification::activated), this, &SpecialNotifierJob::slotOpenMail);
+        connect(notification, &KNotification::closed, this, &SpecialNotifierJob::deleteLater);
 
         notification->sendEvent();
-        if ( NewMailNotifierAgentSettings::beepOnNewMails() ) {
+        if (NewMailNotifierAgentSettings::beepOnNewMails()) {
             KNotification::beep();
         }
     } else {
-        emit displayNotification(pixmap, result.join(QLatin1String("\n")));
+        Q_EMIT displayNotification(pixmap, result.join(QStringLiteral("\n")));
         deleteLater();
     }
 }
