@@ -17,34 +17,33 @@
     02110-1301, USA.
 */
 
-
 #ifndef ENTITYTREECREATEJOB_H
 #define ENTITYTREECREATEJOB_H
 
-#include <Akonadi/Job>
-#include <Akonadi/Collection>
-#include <Akonadi/Item>
-#include <Akonadi/TransactionSequence>
+#include <AkonadiCore/Job>
+#include <AkonadiCore/Collection>
+#include <AkonadiCore/Item>
+#include <AkonadiCore/TransactionSequence>
 
 class EntityTreeCreateJob : public Akonadi::TransactionSequence
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  explicit EntityTreeCreateJob( const QList<Akonadi::Collection::List> &collections, const Akonadi::Item::List &items, QObject* parent = 0 );
+    explicit EntityTreeCreateJob(const QList<Akonadi::Collection::List> &collections, const Akonadi::Item::List &items, QObject *parent = Q_NULLPTR);
 
-  /* reimp */ void doStart();
+    /* reimp */ void doStart();
 
-private slots:
-  void collectionCreateJobDone( KJob * );
+private Q_SLOTS:
+    void collectionCreateJobDone(KJob *);
 
 private:
-  void createNextLevelOfCollections();
-  void createReadyItems();
+    void createNextLevelOfCollections();
+    void createReadyItems();
 
 private:
-  QList<Akonadi::Collection::List> m_collections;
-  Akonadi::Item::List m_items;
-  int m_pendingJobs;
+    QList<Akonadi::Collection::List> m_collections;
+    Akonadi::Item::List m_items;
+    int m_pendingJobs;
 };
 
 #endif
