@@ -20,35 +20,37 @@
  */
 
 #include "migratorbase.h"
-#include <KStandardDirs>
-#include <KDebug>
+#include <QDebug>
 #include <KComponentData>
 #include <KLocalizedString>
-#include <akonadi/servermanager.h>
+#include <AkonadiCore/servermanager.h>
 #include <QFile>
 #include <QDateTime>
+#include <KGlobal>
+#include <QStandardPaths>
+#include <QFileInfo>
+#include <QDir>
 
 static QString messageTypeToString(MigratorBase::MessageType type)
 {
     switch (type) {
-        case MigratorBase::Success: return QLatin1String("Success");
-        case MigratorBase::Skip:    return QLatin1String("Skipped");
-        case MigratorBase::Info:    return QLatin1String("Info   ");
-        case MigratorBase::Warning: return QLatin1String("WARNING");
-        case MigratorBase::Error:   return QLatin1String("ERROR  ");
+    case MigratorBase::Success: return QStringLiteral("Success");
+    case MigratorBase::Skip:    return QStringLiteral("Skipped");
+    case MigratorBase::Info:    return QStringLiteral("Info   ");
+    case MigratorBase::Warning: return QStringLiteral("WARNING");
+    case MigratorBase::Error:   return QStringLiteral("ERROR  ");
     }
     Q_ASSERT(false);
     return QString();
 }
 
-
 static QMap<QString, MigratorBase::MigrationState> fillMigrationStateMapping()
 {
     QMap<QString, MigratorBase::MigrationState> map;
-    map.insert(QLatin1String("Complete"), MigratorBase::Complete);
-    map.insert(QLatin1String("Aborted"), MigratorBase::Aborted);
-    map.insert(QLatin1String("InProgress"), MigratorBase::InProgress);
-    map.insert(QLatin1String("Failed"), MigratorBase::Failed);
+    map.insert(QStringLiteral("Complete"), MigratorBase::Complete);
+    map.insert(QStringLiteral("Aborted"), MigratorBase::Aborted);
+    map.insert(QStringLiteral("InProgress"), MigratorBase::InProgress);
+    map.insert(QStringLiteral("Failed"), MigratorBase::Failed);
     return map;
 }
 
@@ -67,27 +69,29 @@ static MigratorBase::MigrationState identifierToState(const QString &identifier)
 }
 
 MigratorBase::MigratorBase(const QString &identifier, QObject *parent)
-:   QObject(parent),
-    mIdentifier(identifier),
-    mMigrationState(None),
-    mConfig(new KConfig(Akonadi::ServerManager::addNamespace(QLatin1String("akonadi-migrationrc"))))
+    :   QObject(parent),
+        mIdentifier(identifier),
+        mMigrationState(None),
+        mConfig(new KConfig(Akonadi::ServerManager::addNamespace(QStringLiteral("akonadi-migrationrc"))))
 {
-    const QString logFileName = KStandardDirs::locateLocal("data", KGlobal::mainComponent().componentName() + QLatin1String("/") + identifier + QLatin1String("migration.log"));
+    const QString logFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + KGlobal::mainComponent().componentName() + QStringLiteral("/") + identifier + QStringLiteral("migration.log");
+    QFileInfo fileInfo(logFileName);
+    QDir().mkpath(fileInfo.absolutePath());
     setLogfile(logFileName);
-    connect(this, SIGNAL(message(MigratorBase::MessageType,QString)), SLOT(logMessage(MigratorBase::MessageType,QString)));
+    connect(this, &MigratorBase::message, this, &MigratorBase::logMessage);
     loadState();
 }
 
 MigratorBase::MigratorBase(const QString &identifier, const QString &configFile, const QString &logFile, QObject *parent)
-:   QObject(parent),
-    mIdentifier(identifier),
-    mMigrationState(None)
+    :   QObject(parent),
+        mIdentifier(identifier),
+        mMigrationState(None)
 {
     if (!configFile.isEmpty()) {
         mConfig.reset(new KConfig(configFile));
     }
     setLogfile(logFile);
-    connect(this, SIGNAL(message(MigratorBase::MessageType,QString)), SLOT(logMessage(MigratorBase::MessageType,QString)));
+    connect(this, &MigratorBase::message, this, &MigratorBase::logMessage);
     loadState();
 }
 
@@ -102,7 +106,7 @@ void MigratorBase::setLogfile(const QString &logfile)
         mLogFile.reset(new QFile(logfile));
         if (!mLogFile->open(QFile::Append)) {
             mLogFile.reset();
-            kWarning() << "Unable to open log file: " << logfile;
+            qWarning() << "Unable to open log file: " << logfile;
         }
     } else {
         mLogFile.reset();
@@ -135,7 +139,7 @@ QString MigratorBase::logfile() const
 bool MigratorBase::canStart()
 {
     if (mIdentifier.isEmpty()) {
-        emit message(Error, i18n("Missing Identifier"));
+        Q_EMIT message(Error, i18n("Missing Identifier"));
         return false;
     }
     return true;
@@ -144,17 +148,17 @@ bool MigratorBase::canStart()
 void MigratorBase::start()
 {
     if (mMigrationState == InProgress) {
-        kWarning() << "already running";
+        qWarning() << "already running";
         return;
     }
     if (!canStart()) {
-        emit message(Error, i18n("Failed to start migration because migrator is not ready"));
-        emit stoppedProcessing();
+        Q_EMIT message(Error, i18n("Failed to start migration because migrator is not ready"));
+        Q_EMIT stoppedProcessing();
         return;
     }
     //TODO acquire dbus lock
     logMessage(Info, displayName());
-    emit message(Info, i18n("Starting migration..."));
+    Q_EMIT message(Info, i18n("Starting migration..."));
     setMigrationState(InProgress);
     setProgress(0);
     startWork();
@@ -162,24 +166,24 @@ void MigratorBase::start()
 
 void MigratorBase::pause()
 {
-    kWarning() << "pause is not implemented";
+    qWarning() << "pause is not implemented";
 }
 
 void MigratorBase::resume()
 {
-    kWarning() << "resume is not implemented";
+    qWarning() << "resume is not implemented";
 }
 
 void MigratorBase::abort()
 {
-    kWarning() << "abort is not implemented";
+    qWarning() << "abort is not implemented";
 }
 
 void MigratorBase::logMessage(MigratorBase::MessageType type, const QString &msg)
 {
     if (mLogFile) {
-        mLogFile->write(QString(QLatin1Char('[') + QDateTime::currentDateTime().toString() + QLatin1String("] ")
-        + messageTypeToString(type) + QLatin1String(": ") + msg + QLatin1Char('\n')).toUtf8());
+        mLogFile->write(QString(QLatin1Char('[') + QDateTime::currentDateTime().toString() + QStringLiteral("] ")
+                                + messageTypeToString(type) + QStringLiteral(": ") + msg + QLatin1Char('\n')).toUtf8());
         mLogFile->flush();
     }
 }
@@ -193,32 +197,32 @@ void MigratorBase::setMigrationState(MigratorBase::MigrationState state)
 {
     mMigrationState = state;
     switch (state) {
-        case Complete:
-            setProgress(100);
-            emit message(Success, i18n("Migration complete"));
-            emit stoppedProcessing();
-            break;
-        case Aborted:
-            emit message(Skip, i18n("Migration aborted"));
-            emit stoppedProcessing();
-            break;
-        case InProgress:
-            break;
-        case Failed:
-            emit message(Error, i18n("Migration failed"));
-            emit stoppedProcessing();
-            break;
-        case Paused:
-            emit message(Info, i18n("Migration paused"));
-            emit stateChanged(mMigrationState);
-            return;
-        default:
-            kWarning() << "invalid state " << state;
-            Q_ASSERT(false);
-            return;
+    case Complete:
+        setProgress(100);
+        Q_EMIT message(Success, i18n("Migration complete"));
+        Q_EMIT stoppedProcessing();
+        break;
+    case Aborted:
+        Q_EMIT message(Skip, i18n("Migration aborted"));
+        Q_EMIT stoppedProcessing();
+        break;
+    case InProgress:
+        break;
+    case Failed:
+        Q_EMIT message(Error, i18n("Migration failed"));
+        Q_EMIT stoppedProcessing();
+        break;
+    case Paused:
+        Q_EMIT message(Info, i18n("Migration paused"));
+        Q_EMIT stateChanged(mMigrationState);
+        return;
+    default:
+        qWarning() << "invalid state " << state;
+        Q_ASSERT(false);
+        return;
     }
     saveState();
-    emit stateChanged(mMigrationState);
+    Q_EMIT stateChanged(mMigrationState);
 }
 
 MigratorBase::MigrationState MigratorBase::migrationState() const
@@ -228,26 +232,26 @@ MigratorBase::MigrationState MigratorBase::migrationState() const
 
 void MigratorBase::saveState()
 {
-    config().writeEntry(QLatin1String("MigrationState"), stateToIdentifier(mMigrationState));
+    config().writeEntry(QStringLiteral("MigrationState"), stateToIdentifier(mMigrationState));
 }
 
 void MigratorBase::loadState()
 {
-    const QString state = config().readEntry(QLatin1String("MigrationState"), QString());
+    const QString state = config().readEntry(QStringLiteral("MigrationState"), QString());
     if (!state.isEmpty()) {
         mMigrationState = identifierToState(state);
     }
 
     if (mMigrationState == InProgress) {
-        emit message(Warning, i18n("This migration has already been started once but was aborted"));
+        Q_EMIT message(Warning, i18n("This migration has already been started once but was aborted"));
         mMigrationState = NeedsUpdate;
     }
     switch (mMigrationState) {
-        case Complete:
-            mProgress = 100;
-            break;
-        default:
-            mProgress = 0;
+    case Complete:
+        mProgress = 100;
+        break;
+    default:
+        mProgress = 0;
     }
 }
 
@@ -268,20 +272,20 @@ void MigratorBase::setProgress(int prog)
 {
     if (mProgress != prog) {
         mProgress = prog;
-        emit progress(prog);
+        Q_EMIT progress(prog);
     }
 }
 
 QString MigratorBase::status() const
 {
     switch (mMigrationState) {
-        case None: return i18nc("@info:status", "Not started");
-        case InProgress: return i18nc("@info:status", "Running...");
-        case Complete: return i18nc("@info:status", "Complete");
-        case Aborted: return i18nc("@info:status", "Aborted");
-        case Paused: return i18nc("@info:status", "Paused");
-        case NeedsUpdate: return i18nc("@info:status", "Needs Update");
-        case Failed: return i18nc("@info:status", "Failed");
+    case None: return i18nc("@info:status", "Not started");
+    case InProgress: return i18nc("@info:status", "Running...");
+    case Complete: return i18nc("@info:status", "Complete");
+    case Aborted: return i18nc("@info:status", "Aborted");
+    case Paused: return i18nc("@info:status", "Paused");
+    case NeedsUpdate: return i18nc("@info:status", "Needs Update");
+    case Failed: return i18nc("@info:status", "Failed");
     }
     return QString();
 }
