@@ -21,10 +21,10 @@ using namespace FolderArchive;
 
 QString FolderArchiveUtil::groupConfigPattern()
 {
-    return QLatin1String("FolderArchiveAccount ");
+    return QStringLiteral("FolderArchiveAccount ");
 }
 
 QString FolderArchiveUtil::configFileName()
 {
-    return QLatin1String("foldermailarchiverc");
+    return QStringLiteral("foldermailarchiverc");
 }
