@@ -18,16 +18,16 @@
 #ifndef GOOGLERESOURCE_H
 #define GOOGLERESOURCE_H
 
-#include <Akonadi/ResourceBase>
-#include <Akonadi/AgentBase>
+#include <AkonadiAgentBase/ResourceBase>
+#include <AkonadiAgentBase/AgentBase>
 
-#include <QtGui/qwindowdefs.h>
+#include <qwindowdefs.h>
 
 #include "googleaccountmanager.h"
 
-#include <LibKGAPI2/Types>
+#include <KGAPI/Types>
 
-#include <KDE/KLocalizedString>
+#include <KLocalizedString>
 
 #define ITEM_PROPERTY "_AkonadiItem"
 #define ITEMLIST_PROPERTY "_AkonadiItemList"
@@ -42,57 +42,58 @@ class Job;
 class GoogleSettings;
 
 class GoogleResource : public Akonadi::ResourceBase,
-                       public Akonadi::AgentBase::ObserverV2
+    public Akonadi::AgentBase::ObserverV2
 {
     Q_OBJECT
 
-  public:
-    explicit GoogleResource( const QString &id );
+public:
+    explicit GoogleResource(const QString &id);
     virtual ~GoogleResource();
 
-    virtual GoogleSettings* settings() const = 0;
+    virtual GoogleSettings *settings() const = 0;
     virtual QList<QUrl> scopes() const = 0;
 
-    void cleanup();
+    void cleanup() Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
-    virtual void configure( WId windowId );
+    void configure(WId windowId) Q_DECL_OVERRIDE;
 
     void reloadConfig();
 
-  protected Q_SLOTS:
-    virtual bool retrieveItem( const Akonadi::Item &item, const QSet< QByteArray > &parts );
+protected Q_SLOTS:
+    bool retrieveItem(const Akonadi::Item &item, const QSet< QByteArray > &parts) Q_DECL_OVERRIDE;
 
-    bool handleError( KGAPI2::Job *job );
+    bool handleError(KGAPI2::Job *job);
 
-    virtual void slotAuthJobFinished( KGAPI2::Job *job );
-    virtual void slotGenericJobFinished( KGAPI2::Job *job );
+    virtual void slotAuthJobFinished(KGAPI2::Job *job);
+    virtual void slotGenericJobFinished(KGAPI2::Job *job);
 
-    void emitPercent( KGAPI2::Job* job, int processedCount, int totalCount );
+    void emitPercent(KGAPI2::Job *job, int processedCount, int totalCount);
 
     virtual void slotAbortRequested();
-    virtual void slotAccountManagerReady( bool success );
-    virtual void slotAccountChanged( const KGAPI2::AccountPtr &account );
-    virtual void slotAccountRemoved( const QString &accountName );
+    virtual void slotAccountManagerReady(bool success);
+    virtual void slotAccountChanged(const KGAPI2::AccountPtr &account);
+    virtual void slotAccountRemoved(const QString &accountName);
 
 #ifdef HAVE_ACCOUNTS
-    void slotKAccountsCredentialsReceived( KJob *job );
-    void slotKAccountsAccountInfoReceived( KGAPI2::Job *job );
-    void finishKAccountsAuthentication( KGAPI2::Job* job );
+    void slotKAccountsCredentialsReceived(KJob *job);
+    void slotKAccountsAccountInfoReceived(KGAPI2::Job *job);
+    void finishKAccountsAuthentication(KGAPI2::Job *job);
 #endif // HAVE_ACCOUNTS
 
-  protected:
-    bool configureKAccounts( int accountId, KGAPI2::Job *restartJob = 0 );
-    bool configureKGAPIAccount( const KGAPI2::AccountPtr &account );
-    void updateAccountToken( const KGAPI2::AccountPtr &account, KGAPI2::Job *restartJob = 0 );
+protected:
+    bool configureKAccounts(int accountId, KGAPI2::Job *restartJob = Q_NULLPTR);
+    bool configureKGAPIAccount(const KGAPI2::AccountPtr &account);
+    void updateAccountToken(const KGAPI2::AccountPtr &account, KGAPI2::Job *restartJob = Q_NULLPTR);
 
     template <typename T>
-    bool canPerformTask( const Akonadi::Item &item, const QString &mimeType = QString() ) {
-        if ( item.isValid() && !item.hasPayload<T>()) {
-            cancelTask( i18n( "Invalid item payload." ) );
+    bool canPerformTask(const Akonadi::Item &item, const QString &mimeType = QString())
+    {
+        if (item.isValid() && !item.hasPayload<T>()) {
+            cancelTask(i18n("Invalid item payload."));
             return false;
-        } else if ( item.isValid() && mimeType != item.mimeType() ) {
-            cancelTask( i18n( "Invalid payload mimetype. Expected %1, found %2", mimeType, item.mimeType() ) );
+        } else if (item.isValid() && mimeType != item.mimeType()) {
+            cancelTask(i18n("Invalid payload mimetype. Expected %1, found %2", mimeType, item.mimeType()));
             return false;
         }
 
@@ -109,16 +110,14 @@ public Q_SLOTS:
      */
     int accountId() const;
 
+    GoogleAccountManager *accountManager() const;
 
-    GoogleAccountManager* accountManager() const;
+    void aboutToQuit() Q_DECL_OVERRIDE;
 
-    virtual void aboutToQuit();
-
-
-    virtual int runConfigurationDialog( WId windowId ) = 0;
+    virtual int runConfigurationDialog(WId windowId) = 0;
     virtual void updateResourceName() = 0;
 
-  private:
+private:
     void abort();
 
     bool m_isConfiguring;
