@@ -30,16 +30,21 @@
 #include "messagehelper.h"
 #include "batchfetcher.h"
 
-#include <akonadi/cachepolicy.h>
-#include <akonadi/collectionstatistics.h>
-#include <akonadi/kmime/messageparts.h>
-#include <akonadi/agentbase.h>
-#include <akonadi/itemfetchjob.h>
-#include <akonadi/itemfetchscope.h>
-#include <akonadi/session.h>
+#include <AkonadiCore/cachepolicy.h>
+#include <AkonadiCore/collectionstatistics.h>
+#include <Akonadi/KMime/MessageParts>
+#include <AkonadiAgentBase/agentbase.h>
+#include <AkonadiCore/itemfetchjob.h>
+#include <AkonadiCore/itemfetchscope.h>
+#include <AkonadiCore/session.h>
 
-#include <KDE/KDebug>
-#include <KDE/KLocale>
+#include "imapresource_debug.h"
+#include "imapresource_debug.h"
+
+#include "imapresource_debug.h"
+#include "imapresource_debug.h"
+
+#include <KLocalizedString>
 
 #include <kimap/expungejob.h>
 #include <kimap/fetchjob.h>
@@ -49,12 +54,12 @@
 
 RetrieveItemsTask::RetrieveItemsTask(ResourceStateInterface::Ptr resource, QObject *parent)
     : ResourceTask(CancelIfNoSession, resource, parent),
-    m_session(0),
-    m_fetchedMissingBodies(-1),
-    m_fetchMissingBodies(false),
-    m_batchFetcher(0),
-    m_uidBasedFetch(true),
-    m_flagsChanged(false)
+      m_session(Q_NULLPTR),
+      m_fetchedMissingBodies(-1),
+      m_fetchMissingBodies(false),
+      m_batchFetcher(Q_NULLPTR),
+      m_uidBasedFetch(true),
+      m_flagsChanged(false)
 {
 
 }
@@ -73,9 +78,9 @@ void RetrieveItemsTask::doStart(KIMAP::Session *session)
     emitPercent(0);
     // Prevent fetching items from noselect folders.
     if (collection().hasAttribute("noselect")) {
-        NoSelectAttribute* noselect = static_cast<NoSelectAttribute*>(collection().attribute("noselect"));
+        NoSelectAttribute *noselect = static_cast<NoSelectAttribute *>(collection().attribute("noselect"));
         if (noselect->noSelect()) {
-            kDebug(5327) << "No Select folder";
+            qCDebug(IMAPRESOURCE_LOG) << "No Select folder";
             itemsRetrievalDone();
             return;
         }
@@ -85,24 +90,24 @@ void RetrieveItemsTask::doStart(KIMAP::Session *session)
 
     const Akonadi::Collection col = collection();
     if (m_fetchMissingBodies && col.cachePolicy()
-        .localParts().contains( QLatin1String(Akonadi::MessagePart::Body))) { //disconnected mode, make sure we really have the body cached
+            .localParts().contains(QLatin1String(Akonadi::MessagePart::Body))) {  //disconnected mode, make sure we really have the body cached
 
         Akonadi::Session *session = new Akonadi::Session(resourceName().toLatin1() + "_body_checker", this);
         Akonadi::ItemFetchJob *fetchJob = new Akonadi::ItemFetchJob(col, session);
         fetchJob->fetchScope().setCheckForCachedPayloadPartsOnly();
         fetchJob->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Body);
         fetchJob->fetchScope().setFetchModificationTime(false);
-        connect(fetchJob, SIGNAL(result(KJob*)), this, SLOT(fetchItemsWithoutBodiesDone(KJob*)));
-        connect(fetchJob, SIGNAL(result(KJob*)), session, SLOT(deleteLater()));
+        connect(fetchJob, &Akonadi::ItemFetchJob::result, this, &RetrieveItemsTask::fetchItemsWithoutBodiesDone);
+        connect(fetchJob, &Akonadi::ItemFetchJob::result, session, &Akonadi::Session::deleteLater);
     } else {
         startRetrievalTasks();
     }
 }
 
-BatchFetcher* RetrieveItemsTask::createBatchFetcher(MessageHelper::Ptr messageHelper,
-                                                    const KIMAP::ImapSet &set,
-                                                    const KIMAP::FetchJob::FetchScope &scope,
-                                                    int batchSize, KIMAP::Session* session)
+BatchFetcher *RetrieveItemsTask::createBatchFetcher(MessageHelper::Ptr messageHelper,
+        const KIMAP::ImapSet &set,
+        const KIMAP::FetchJob::FetchScope &scope,
+        int batchSize, KIMAP::Session *session)
 {
     return new BatchFetcher(messageHelper, set, scope, batchSize, session);
 }
@@ -111,21 +116,21 @@ void RetrieveItemsTask::fetchItemsWithoutBodiesDone(KJob *job)
 {
     QList<qint64> uids;
     if (job->error()) {
-        kWarning() << job->errorString();
+        qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
         return;
     } else {
         int i = 0;
-        Akonadi::ItemFetchJob *fetch = static_cast<Akonadi::ItemFetchJob*>(job);
-        Q_FOREACH(const Akonadi::Item &item, fetch->items())  {
+        Akonadi::ItemFetchJob *fetch = static_cast<Akonadi::ItemFetchJob *>(job);
+        Q_FOREACH (const Akonadi::Item &item, fetch->items())  {
             if (!item.cachedPayloadParts().contains(Akonadi::MessagePart::Body)) {
-                kWarning() << "Item " << item.id() << " is missing the payload! Cached payloads: " << item.cachedPayloadParts();
+                qCWarning(IMAPRESOURCE_LOG) << "Item " << item.id() << " is missing the payload! Cached payloads: " << item.cachedPayloadParts();
                 uids.append(item.remoteId().toInt());
                 i++;
             }
         }
         if (i > 0) {
-            kWarning() << "Number of items missing the body: " << i;
+            qCWarning(IMAPRESOURCE_LOG) << "Number of items missing the body: " << i;
         }
     }
     onFetchItemsWithoutBodiesDone(uids);
@@ -137,16 +142,15 @@ void RetrieveItemsTask::onFetchItemsWithoutBodiesDone(const QList<qint64> &items
     startRetrievalTasks();
 }
 
-
 void RetrieveItemsTask::startRetrievalTasks()
 {
     const QString mailBox = mailBoxForCollection(collection());
-    kDebug(5327) << "Starting retrieval for " << mailBox;
+    qCDebug(IMAPRESOURCE_LOG) << "Starting retrieval for " << mailBox;
     m_time.start();
 
     // Now is the right time to expunge the messages marked \\Deleted from this mailbox.
     // We assume that we can only expunge if we can delete items (correct would be to check for "e" ACL right).
-    if (isAutomaticExpungeEnabled() && (collection().rights() & Akonadi::Collection::CanDeleteItem)) {
+    if (isAutomaticExpungeEnabled() && (!serverCapabilities().contains(QLatin1String("ACL")) || (myRights(collection()) & KIMAP::Acl::Expunge))) {
         if (m_session->selectedMailBox() != mailBox) {
             triggerPreExpungeSelect(mailBox);
         } else {
@@ -163,18 +167,18 @@ void RetrieveItemsTask::triggerPreExpungeSelect(const QString &mailBox)
     KIMAP::SelectJob *select = new KIMAP::SelectJob(m_session);
     select->setMailBox(mailBox);
     select->setCondstoreEnabled(serverSupportsCondstore());
-    connect(select, SIGNAL(result(KJob*)),
-            this, SLOT(onPreExpungeSelectDone(KJob*)));
+    connect(select, &KJob::result,
+            this, &RetrieveItemsTask::onPreExpungeSelectDone);
     select->start();
 }
 
 void RetrieveItemsTask::onPreExpungeSelectDone(KJob *job)
 {
     if (job->error()) {
-        kWarning() << job->errorString();
+        qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
     } else {
-        KIMAP::SelectJob *select = static_cast<KIMAP::SelectJob*>(job);
+        KIMAP::SelectJob *select = static_cast<KIMAP::SelectJob *>(job);
         triggerExpunge(select->mailBox());
     }
 }
@@ -182,8 +186,8 @@ void RetrieveItemsTask::onPreExpungeSelectDone(KJob *job)
 void RetrieveItemsTask::triggerExpunge(const QString &mailBox)
 {
     KIMAP::ExpungeJob *expunge = new KIMAP::ExpungeJob(m_session);
-    connect(expunge, SIGNAL(result(KJob*)),
-            this, SLOT(onExpungeDone(KJob*)));
+    connect(expunge, &KJob::result,
+            this, &RetrieveItemsTask::onExpungeDone);
     expunge->start();
 }
 
@@ -192,11 +196,11 @@ void RetrieveItemsTask::onExpungeDone(KJob *job)
     // We can ignore the error, we just had a wrong expunge so some old messages will just reappear.
     // TODO we should probably hide messages that are marked as deleted (skipping will not work because we rely on the message count)
     if (job->error()) {
-        kWarning() << "Expunge failed: " << job->errorString();
+        qCWarning(IMAPRESOURCE_LOG) << "Expunge failed: " << job->errorString();
     }
     // Except for network errors.
     if (job->error() && m_session->state() == KIMAP::Session::Disconnected) {
-        cancelTask( job->errorString() );
+        cancelTask(job->errorString());
         return;
     }
 
@@ -210,20 +214,20 @@ void RetrieveItemsTask::triggerFinalSelect(const QString &mailBox)
     KIMAP::SelectJob *select = new KIMAP::SelectJob(m_session);
     select->setMailBox(mailBox);
     select->setCondstoreEnabled(serverSupportsCondstore());
-    connect( select, SIGNAL(result(KJob*)),
-            this, SLOT(onFinalSelectDone(KJob*)) );
+    connect(select, &KJob::result,
+            this, &RetrieveItemsTask::onFinalSelectDone);
     select->start();
 }
 
 void RetrieveItemsTask::onFinalSelectDone(KJob *job)
 {
     if (job->error()) {
-        kWarning() << job->errorString();
+        qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
         return;
     }
 
-    KIMAP::SelectJob *select = qobject_cast<KIMAP::SelectJob*>(job);
+    KIMAP::SelectJob *select = qobject_cast<KIMAP::SelectJob *>(job);
 
     const QString mailBox = select->mailBox();
     const int messageCount = select->messageCount();
@@ -235,7 +239,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     //This is known to happen with Courier IMAP. A better solution would be to issue STATUS in case UIDNEXT is not delivered on select,
     //but that would have to be implemented in KIMAP first. See Bug 338186.
     if (nextUid < 0) {
-        kWarning() << "Server bug: Your IMAP Server delivered an invalid UIDNEXT value. This is a known problem with Courier IMAP.";
+        qCWarning(IMAPRESOURCE_LOG) << "Server bug: Your IMAP Server delivered an invalid UIDNEXT value. This is a known problem with Courier IMAP.";
         nextUid = 0;
     }
 
@@ -250,12 +254,12 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     // Get the current uid validity value and store it
     int oldUidValidity = 0;
     if (!col.hasAttribute("uidvalidity")) {
-        UidValidityAttribute* currentUidValidity  = new UidValidityAttribute(uidValidity);
+        UidValidityAttribute *currentUidValidity  = new UidValidityAttribute(uidValidity);
         col.addAttribute(currentUidValidity);
         modifyNeeded = true;
     } else {
-        UidValidityAttribute* currentUidValidity =
-        static_cast<UidValidityAttribute*>(col.attribute("uidvalidity" ));
+        UidValidityAttribute *currentUidValidity =
+            static_cast<UidValidityAttribute *>(col.attribute("uidvalidity"));
         oldUidValidity = currentUidValidity->uidValidity();
         if (oldUidValidity != uidValidity) {
             currentUidValidity->setUidValidity(uidValidity);
@@ -266,7 +270,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     // Get the current uid next value and store it
     int oldNextUid = 0;
     if (nextUid > 0) { //this can fail with faulty servers that don't deliver uidnext
-        if (UidNextAttribute* currentNextUid = col.attribute<UidNextAttribute>()) {
+        if (UidNextAttribute *currentNextUid = col.attribute<UidNextAttribute>()) {
             oldNextUid = currentNextUid->uidNext();
             if (oldNextUid != nextUid) {
                 currentNextUid->setUidNext(nextUid);
@@ -285,7 +289,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
         modifyNeeded = true;
     } else {
         Akonadi::CollectionFlagsAttribute *flagsAttribute =
-        static_cast<Akonadi::CollectionFlagsAttribute*>(col.attribute("collectionflags"));
+            static_cast<Akonadi::CollectionFlagsAttribute *>(col.attribute("collectionflags"));
         const QList<QByteArray> oldFlags = flagsAttribute->flags();
         if (oldFlags != flags) {
             flagsAttribute->setFlags(flags);
@@ -317,7 +321,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     }
     m_highestModseq = oldHighestModSeq;
 
-    if ( modifyNeeded ) {
+    if (modifyNeeded) {
         m_modifiedCollection = col;
     }
 
@@ -325,17 +329,17 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     scope.parts.clear();
     scope.mode = KIMAP::FetchJob::FetchScope::FullHeaders;
 
-    if ( col.cachePolicy()
-        .localParts().contains( QLatin1String(Akonadi::MessagePart::Body) ) ) {
+    if (col.cachePolicy()
+            .localParts().contains(QLatin1String(Akonadi::MessagePart::Body))) {
         scope.mode = KIMAP::FetchJob::FetchScope::Full;
     }
 
     const qint64 realMessageCount = col.statistics().count();
 
-    kDebug(5327) << "Starting message retrieval. Elapsed(ms): " << m_time.elapsed();
-    kDebug(5327) << "MessageCount: " << messageCount << "Local message count: " << realMessageCount;
-    kDebug(5327) << "UidNext: " << nextUid << "Local UidNext: "<< oldNextUid;
-    kDebug(5327) << "HighestModSeq: " << highestModSeq << "Local HighestModSeq: "<< oldHighestModSeq;
+    qCDebug(IMAPRESOURCE_LOG) << "Starting message retrieval. Elapsed(ms): " << m_time.elapsed();
+    qCDebug(IMAPRESOURCE_LOG) << "MessageCount: " << messageCount << "Local message count: " << realMessageCount;
+    qCDebug(IMAPRESOURCE_LOG) << "UidNext: " << nextUid << "Local UidNext: " << oldNextUid;
+    qCDebug(IMAPRESOURCE_LOG) << "HighestModSeq: " << highestModSeq << "Local HighestModSeq: " << oldHighestModSeq;
 
     /*
     * A synchronization has 3 mandatory steps:
@@ -349,7 +353,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     * have been deleted remotely, if we locally have messages that were not yet uploaded.
     * We cannot differentiate that from remotely removed messages, so we have to do a full flag
     * listing in that case. This can be optimized once we support QRESYNC and therefore have a way
-    * to determine wether messages have been removed.
+    * to determine whether messages have been removed.
     */
 
     if (messageCount == 0) {
@@ -357,27 +361,27 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
         //If no messages are present on the server, clear local cash and finish
         m_incremental = false;
         if (realMessageCount > 0) {
-            kDebug( 5327 ) << "No messages present so we are done, deleting local messages.";
+            qCDebug(IMAPRESOURCE_LOG) << "No messages present so we are done, deleting local messages.";
             itemsRetrieved(Akonadi::Item::List());
         } else {
-            kDebug( 5327 ) << "No messages present so we are done";
+            qCDebug(IMAPRESOURCE_LOG) << "No messages present so we are done";
         }
         taskComplete();
-    } else if (oldUidValidity != uidValidity) {
+    } else if (oldUidValidity != uidValidity || nextUid <= 0) {
         //If uidvalidity has changed our local cache is worthless and has to be refetched completely
-        if (oldUidValidity != 0) {
-            kDebug( 5327 ) << "UIDVALIDITY check failed (" << oldUidValidity << "|"
-                            << uidValidity << ") refetching " << mailBox;
-        } else {
-            kDebug( 5327 ) << "Fetching complete mailbox " << mailBox;
+        if (oldUidValidity != 0 && oldUidValidity != uidValidity) {
+            qCDebug(IMAPRESOURCE_LOG) << "UIDVALIDITY check failed (" << oldUidValidity << "|" << uidValidity << ")";
         }
-
+        if (nextUid <= 0) {
+            qCDebug(IMAPRESOURCE_LOG) << "Invalid UIDNEXT";
+        }
+        qCDebug(IMAPRESOURCE_LOG) << "Fetching complete mailbox " << mailBox;
         setTotalItems(messageCount);
-        retrieveItems(KIMAP::ImapSet(1, nextUid), scope, false, true);
+        retrieveItems(KIMAP::ImapSet(1, 0), scope, false, true);
     } else if (nextUid <= 0) {
         //This is a compatibilty codepath for Courier IMAP. It probably introduces problems, but at least it syncs.
         //Since we don't have uidnext available, we simply use the messagecount. This will miss simultaneously added/removed messages.
-        kDebug() << "Running courier imap compatiblity codepath";
+        //qCDebug(IMAPRESOURCE_LOG) << "Running courier imap compatibility codepath";
         if (messageCount > realMessageCount) {
             //Get new messages
             retrieveItems(KIMAP::ImapSet(realMessageCount + 1, messageCount), scope, false, false);
@@ -404,7 +408,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
         //New messages are available, but we know no messages have been removed.
         //Fetch new messages, and then check for changed flags and removed messages
         //We can make an incremental update and use modseq.
-        kDebug( 5327 ) << "Incrementally fetching new messages: UidNext: " << nextUid << " Old UidNext: " << oldNextUid << " message count " << messageCount << realMessageCount;
+        qCDebug(IMAPRESOURCE_LOG) << "Incrementally fetching new messages: UidNext: " << nextUid << " Old UidNext: " << oldNextUid << " message count " << messageCount << realMessageCount;
         setTotalItems(qMax(1ll, messageCount - realMessageCount));
         m_flagsChanged = !(highestModSeq == oldHighestModSeq);
         retrieveItems(KIMAP::ImapSet(qMax(1, oldNextUid), nextUid), scope, true, true);
@@ -413,13 +417,13 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
         //New messages are available, but not enough to justify the difference between the local and remote message count.
         //This can be triggered if we i.e. clear the local cache, but the keep the annotations.
         //If we didn't catch this case, we end up inserting flags only for every missing message.
-        kWarning() << "Detected inconsistency in local cache, we're missing some messages. Server: " << messageCount << " Local: "<< realMessageCount;
-        kWarning() << "Refetching complete mailbox.";
+        qCWarning(IMAPRESOURCE_LOG) << "Detected inconsistency in local cache, we're missing some messages. Server: " << messageCount << " Local: " << realMessageCount;
+        qCWarning(IMAPRESOURCE_LOG) << "Refetching complete mailbox.";
         setTotalItems(messageCount);
-        retrieveItems(KIMAP::ImapSet(1, nextUid), scope, false, true);
+        retrieveItems(KIMAP::ImapSet(1, 0), scope, false, true);
     } else if (nextUid > oldNextUid) {
         //New messages are available. Fetch new messages, and then check for changed flags and removed messages
-        kDebug( 5327 ) << "Fetching new messages: UidNext: " << nextUid << " Old UidNext: " << oldNextUid;
+        qCDebug(IMAPRESOURCE_LOG) << "Fetching new messages: UidNext: " << nextUid << " Old UidNext: " << oldNextUid;
         setTotalItems(messageCount);
         retrieveItems(KIMAP::ImapSet(qMax(1, oldNextUid), nextUid), scope, false, true);
     } else if (messageCount == realMessageCount && oldNextUid == nextUid) {
@@ -433,7 +437,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
         //Instead we only sync flags when new messages are available or removed and skip this step.
         //WARNING: This sacrifices consistency as we will not detect flag changes until a new message enters the mailbox.
         if (m_incremental && !serverSupportsCondstore()) {
-            kDebug(5327) << "Avoiding flag sync due to missing CONDSTORE support";
+            qCDebug(IMAPRESOURCE_LOG) << "Avoiding flag sync due to missing CONDSTORE support";
             taskComplete();
             return;
         }
@@ -443,8 +447,8 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
         //Error recovery:
         //We didn't detect any new messages based on the uid, but according to the message count there are new ones.
         //Our local cache is invalid and has to be refetched.
-        kWarning() << "Detected inconsistency in local cache, we're missing some messages. Server: " << messageCount << " Local: "<< realMessageCount;
-        kWarning() << "Refetching complete mailbox.";
+        qCWarning(IMAPRESOURCE_LOG) << "Detected inconsistency in local cache, we're missing some messages. Server: " << messageCount << " Local: " << realMessageCount;
+        qCWarning(IMAPRESOURCE_LOG) << "Refetching complete mailbox.";
         setTotalItems(messageCount);
         retrieveItems(KIMAP::ImapSet(1, nextUid), scope, false, true);
     } else {
@@ -457,7 +461,7 @@ void RetrieveItemsTask::onFinalSelectDone(KJob *job)
     }
 }
 
-void RetrieveItemsTask::retrieveItems(const KIMAP::ImapSet& set, const KIMAP::FetchJob::FetchScope &scope, bool incremental, bool uidBased)
+void RetrieveItemsTask::retrieveItems(const KIMAP::ImapSet &set, const KIMAP::FetchJob::FetchScope &scope, bool incremental, bool uidBased)
 {
     Q_ASSERT(set.intervals().size() == 1);
 
@@ -469,7 +473,7 @@ void RetrieveItemsTask::retrieveItems(const KIMAP::ImapSet& set, const KIMAP::Fe
     if (m_uidBasedFetch && set.intervals().size() == 1) {
         m_batchFetcher->setSearchUids(set.intervals().front());
     }
-    m_batchFetcher->setProperty("alreadyFetched", set.intervals().first().begin());
+    m_batchFetcher->setProperty("alreadyFetched", set.intervals().at(0).begin());
     connect(m_batchFetcher, SIGNAL(itemsRetrieved(Akonadi::Item::List)),
             this, SLOT(onItemsRetrieved(Akonadi::Item::List)));
     connect(m_batchFetcher, SIGNAL(result(KJob*)),
@@ -497,16 +501,16 @@ void RetrieveItemsTask::onItemsRetrieved(const Akonadi::Item::List &addedItems)
     if (m_fetchedMissingBodies != -1) {
         const QString mailBox = mailBoxForCollection(collection());
         m_fetchedMissingBodies += addedItems.count();
-        emit status(Akonadi::AgentBase::Running,
-                    i18nc( "@info:status", "Fetching missing mail bodies in %3: %1/%2", m_fetchedMissingBodies, m_messageUidsMissingBody.count(), mailBox));
+        Q_EMIT status(Akonadi::AgentBase::Running,
+                      i18nc("@info:status", "Fetching missing mail bodies in %3: %1/%2", m_fetchedMissingBodies, m_messageUidsMissingBody.count(), mailBox));
     }
 }
 
 void RetrieveItemsTask::onRetrievalDone(KJob *job)
 {
-    m_batchFetcher = 0;
+    m_batchFetcher = Q_NULLPTR;
     if (job->error()) {
-        kWarning() << job->errorString();
+        qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
         m_fetchedMissingBodies = -1;
         return;
@@ -529,42 +533,42 @@ void RetrieveItemsTask::onRetrievalDone(KJob *job)
     listFlagsForImapSet(KIMAP::ImapSet(1, alreadyFetchedBegin - 1));
 }
 
-void RetrieveItemsTask::listFlagsForImapSet(const KIMAP::ImapSet& set)
+void RetrieveItemsTask::listFlagsForImapSet(const KIMAP::ImapSet &set)
 {
-  kDebug(5327) << "Listing flags " << set.intervals().first().begin() << set.intervals().first().end();
-  kDebug(5327) << "Starting flag retrieval. Elapsed(ms): " << m_time.elapsed();
+    qCDebug(IMAPRESOURCE_LOG) << "Listing flags " << set.intervals().at(0).begin() << set.intervals().at(0).end();
+    qCDebug(IMAPRESOURCE_LOG) << "Starting flag retrieval. Elapsed(ms): " << m_time.elapsed();
 
-  KIMAP::FetchJob::FetchScope scope;
-  scope.parts.clear();
-  scope.mode = KIMAP::FetchJob::FetchScope::Flags;
-  // Only use changeSince when doing incremental listings,
-  // otherwise we would overwrite our local data with an incomplete dataset
-  if(m_incremental && serverSupportsCondstore()) {
-      scope.changedSince = m_highestModseq;
-      if (!m_flagsChanged) {
-          kDebug(5327)  << "No flag changes.";
-          taskComplete();
-          return;
-      }
-  }
+    KIMAP::FetchJob::FetchScope scope;
+    scope.parts.clear();
+    scope.mode = KIMAP::FetchJob::FetchScope::Flags;
+    // Only use changeSince when doing incremental listings,
+    // otherwise we would overwrite our local data with an incomplete dataset
+    if (m_incremental && serverSupportsCondstore()) {
+        scope.changedSince = m_highestModseq;
+        if (!m_flagsChanged) {
+            qCDebug(IMAPRESOURCE_LOG)  << "No flag changes.";
+            taskComplete();
+            return;
+        }
+    }
 
-  m_batchFetcher = createBatchFetcher(resourceState()->messageHelper(), set, scope, 10 * batchSize(), m_session);
-  m_batchFetcher->setUidBased(m_uidBasedFetch);
-  if (m_uidBasedFetch && scope.changedSince == 0 && set.intervals().size() == 1) {
-      m_batchFetcher->setSearchUids(set.intervals().front());
-  }
-  connect(m_batchFetcher, SIGNAL(itemsRetrieved(Akonadi::Item::List)),
-          this, SLOT(onItemsRetrieved(Akonadi::Item::List)));
-  connect(m_batchFetcher, SIGNAL(result(KJob*)),
-          this, SLOT(onFlagsFetchDone(KJob*)));
-  m_batchFetcher->start();
+    m_batchFetcher = createBatchFetcher(resourceState()->messageHelper(), set, scope, 10 * batchSize(), m_session);
+    m_batchFetcher->setUidBased(m_uidBasedFetch);
+    if (m_uidBasedFetch && scope.changedSince == 0 && set.intervals().size() == 1) {
+        m_batchFetcher->setSearchUids(set.intervals().front());
+    }
+    connect(m_batchFetcher, SIGNAL(itemsRetrieved(Akonadi::Item::List)),
+            this, SLOT(onItemsRetrieved(Akonadi::Item::List)));
+    connect(m_batchFetcher, SIGNAL(result(KJob*)),
+            this, SLOT(onFlagsFetchDone(KJob*)));
+    m_batchFetcher->start();
 }
 
 void RetrieveItemsTask::onFlagsFetchDone(KJob *job)
 {
-    m_batchFetcher = 0;
-    if ( job->error() ) {
-        kWarning() << job->errorString();
+    m_batchFetcher = Q_NULLPTR;
+    if (job->error()) {
+        qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
     } else {
         taskComplete();
@@ -574,7 +578,7 @@ void RetrieveItemsTask::onFlagsFetchDone(KJob *job)
 void RetrieveItemsTask::taskComplete()
 {
     if (m_modifiedCollection.isValid()) {
-        kDebug(5327) << "Applying collection changes";
+        qCDebug(IMAPRESOURCE_LOG) << "Applying collection changes";
         applyCollectionChanges(m_modifiedCollection);
     }
     if (m_incremental) {
@@ -583,8 +587,7 @@ void RetrieveItemsTask::taskComplete()
         // Akonadi knows we did incremental fetch that came up with no changes
         itemsRetrievedIncremental(Akonadi::Item::List(), Akonadi::Item::List());
     }
-    kDebug(5327) << "Retrieval complete. Elapsed(ms): " << m_time.elapsed();
+    qCDebug(IMAPRESOURCE_LOG) << "Retrieval complete. Elapsed(ms): " << m_time.elapsed();
     itemsRetrievalDone();
 }
 
-#include "retrieveitemstask.moc"
