@@ -20,18 +20,18 @@
 #ifndef UIDVALIDITYATTRIBUTE_H
 #define UIDVALIDITYATTRIBUTE_H
 
-#include <akonadi/attribute.h>
+#include <attribute.h>
 
 class UidValidityAttribute : public Akonadi::Attribute
 {
 public:
-    explicit UidValidityAttribute( int uidvalidity = 0 );
-    void setUidValidity( int uidvalidity );
+    explicit UidValidityAttribute(int uidvalidity = 0);
+    void setUidValidity(int uidvalidity);
     int uidValidity() const;
-    virtual QByteArray type() const;
-    virtual Attribute* clone() const;
-    virtual QByteArray serialized() const;
-    virtual void deserialize( const QByteArray &data );
+    QByteArray type() const Q_DECL_OVERRIDE;
+    Attribute *clone() const Q_DECL_OVERRIDE;
+    QByteArray serialized() const Q_DECL_OVERRIDE;
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 
 private:
     int mUidValidity;
