@@ -20,9 +20,9 @@
 #ifndef MAILDIR_RETRIEVEITEMSJOB_H
 #define MAILDIR_RETRIEVEITEMSJOB_H
 
-#include <Akonadi/Item>
-#include <Akonadi/Job>
-#include <Akonadi/Collection>
+#include <item.h>
+#include <job.h>
+#include <collection.h>
 
 #include "maildir.h"
 
@@ -38,25 +38,25 @@ class TransactionSequence;
  */
 class RetrieveItemsJob : public Akonadi::Job
 {
-  Q_OBJECT
-  public:
-    RetrieveItemsJob( const Akonadi::Collection &collection, const KPIM::Maildir &md, QObject* parent = 0 );
-    void setMimeType( const QString &mimeType );
+    Q_OBJECT
+public:
+    RetrieveItemsJob(const Akonadi::Collection &collection, const KPIM::Maildir &md, QObject *parent = Q_NULLPTR);
+    void setMimeType(const QString &mimeType);
 
-  protected:
-    void doStart();
+protected:
+    void doStart() Q_DECL_OVERRIDE;
 
-  private:
+private:
     void entriesProcessed();
-    Akonadi::TransactionSequence* transaction();
+    Akonadi::TransactionSequence *transaction();
 
-  private slots:
-    void localListDone( KJob *job );
-    void transactionDone( KJob *job );
+private Q_SLOTS:
+    void localListDone(KJob *job);
+    void transactionDone(KJob *job);
     void processEntry();
-    void processEntryDone( KJob * );
+    void processEntryDone(KJob *);
 
-  private:
+private:
     Akonadi::Collection m_collection;
     KPIM::Maildir m_maildir;
     QHash<QString, Akonadi::Item> m_localItems;
