@@ -22,11 +22,12 @@
 #ifndef OXA_FOLDER_H
 #define OXA_FOLDER_H
 
-#include <QtCore/QList>
+#include <QtCore/QVector>
 #include <QtCore/QMap>
 #include <QtCore/QString>
 
-namespace OXA {
+namespace OXA
+{
 
 /**
  * @short A class that contains information about folders on the OX server.
@@ -35,39 +36,36 @@ namespace OXA {
  */
 class Folder
 {
-  public:
+public:
     /**
      * Describes a list of folders.
      */
-    typedef QList<Folder> List;
+    typedef QVector<Folder> List;
 
     /**
      * Describes the status of the folder.
      */
-    enum ObjectStatus
-    {
-      Created, ///< The folder has been created or modified.
-      Deleted  ///< The folder has been deleted.
+    enum ObjectStatus {
+        Created, ///< The folder has been created or modified.
+        Deleted  ///< The folder has been deleted.
     };
 
     /**
      * Describes the visibility type of the folder.
      */
-    enum Type
-    {
-      Public,  ///< The folder is visible for all users.
-      Private  ///< The folder is only visible for the owner.
+    enum Type {
+        Public,  ///< The folder is visible for all users.
+        Private  ///< The folder is only visible for the owner.
     };
 
     /**
      * Describes the module the folder belongs to.
      */
-    enum Module
-    {
-      Unbound,  ///< The folder is only a structural folder.
-      Calendar, ///< The folder contains events.
-      Contacts, ///< The folder contains contacts.
-      Tasks     ///< The folder contains tasks.
+    enum Module {
+        Unbound,  ///< The folder is only a structural folder.
+        Calendar, ///< The folder contains events.
+        Contacts, ///< The folder contains contacts.
+        Tasks     ///< The folder contains tasks.
     };
 
     /**
@@ -76,70 +74,66 @@ class Folder
      */
     class Permissions
     {
-      public:
+    public:
         /**
          * Describes the permissions on folder objects.
          */
-        enum FolderPermission
-        {
-          NoPermission = 0,     ///< No permissions.
-          FolderIsVisible = 2,  ///< The folder can be read.
-          CreateObjects = 4,    ///< Objects can be created in the folder.
-          CreateSubfolders = 8, ///< Subfolders can be created in the folder.
-          AdminPermission = 128 ///< Permissions can be changed.
+        enum FolderPermission {
+            NoPermission = 0,     ///< No permissions.
+            FolderIsVisible = 2,  ///< The folder can be read.
+            CreateObjects = 4,    ///< Objects can be created in the folder.
+            CreateSubfolders = 8, ///< Subfolders can be created in the folder.
+            AdminPermission = 128 ///< Permissions can be changed.
         };
 
         /**
          * Describes the read permissions on other objects.
          */
-        enum ObjectReadPermission
-        {
-          NoReadPermission = 0,     ///< The objects can not be read.
-          ReadOwnObjects = 2,       ///< Only own objects can be read.
-          ReadAllObjects = 4,       ///< All objects can be read.
-          AdminReadPermission = 128
+        enum ObjectReadPermission {
+            NoReadPermission = 0,     ///< The objects can not be read.
+            ReadOwnObjects = 2,       ///< Only own objects can be read.
+            ReadAllObjects = 4,       ///< All objects can be read.
+            AdminReadPermission = 128
         };
 
         /**
          * Describes the write permissions on other objects.
          */
-        enum ObjectWritePermission
-        {
-          NoWritePermission = 0,     ///< The objects can not be written.
-          WriteOwnObjects = 2,       ///< Only own objects can be written.
-          WriteAllObjects = 4,       ///< All objects can be written.
-          AdminWritePermission = 128
+        enum ObjectWritePermission {
+            NoWritePermission = 0,     ///< The objects can not be written.
+            WriteOwnObjects = 2,       ///< Only own objects can be written.
+            WriteAllObjects = 4,       ///< All objects can be written.
+            AdminWritePermission = 128
         };
 
         /**
          * Describes the delete permissions on other objects.
          */
-        enum ObjectDeletePermission
-        {
-          NoDeletePermission = 0,     ///< The objects can not be deleted.
-          DeleteOwnObjects = 2,       ///< Only own objects can be deleted.
-          DeleteAllObjects = 4,       ///< All objects can be deleted.
-          AdminDeletePermission = 128
+        enum ObjectDeletePermission {
+            NoDeletePermission = 0,     ///< The objects can not be deleted.
+            DeleteOwnObjects = 2,       ///< Only own objects can be deleted.
+            DeleteAllObjects = 4,       ///< All objects can be deleted.
+            AdminDeletePermission = 128
         };
 
         Permissions();
 
-        void setFolderPermission( FolderPermission permission );
+        void setFolderPermission(FolderPermission permission);
         FolderPermission folderPermission() const;
 
-        void setObjectReadPermission( ObjectReadPermission permission );
+        void setObjectReadPermission(ObjectReadPermission permission);
         ObjectReadPermission objectReadPermission() const;
 
-        void setObjectWritePermission( ObjectWritePermission permission );
+        void setObjectWritePermission(ObjectWritePermission permission);
         ObjectWritePermission objectWritePermission() const;
 
-        void setObjectDeletePermission( ObjectDeletePermission permission );
+        void setObjectDeletePermission(ObjectDeletePermission permission);
         ObjectDeletePermission objectDeletePermission() const;
 
-        void setAdminFlag( bool value );
+        void setAdminFlag(bool value);
         bool adminFlag() const;
 
-      private:
+    private:
         FolderPermission mFolderPermission;
         ObjectReadPermission mObjectReadPermission;
         ObjectWritePermission mObjectWritePermission;
@@ -152,40 +146,40 @@ class Folder
 
     Folder();
 
-    void setObjectStatus( ObjectStatus status );
+    void setObjectStatus(ObjectStatus status);
     ObjectStatus objectStatus() const;
 
-    void setTitle( const QString &title );
+    void setTitle(const QString &title);
     QString title() const;
 
-    void setType( Type type );
+    void setType(Type type);
     Type type() const;
 
-    void setModule( Module module );
+    void setModule(Module module);
     Module module() const;
 
-    void setObjectId( qlonglong id );
+    void setObjectId(qlonglong id);
     qlonglong objectId() const;
 
-    void setFolderId( qlonglong id );
+    void setFolderId(qlonglong id);
     qlonglong folderId() const;
 
-    void setIsDefaultFolder( bool value );
+    void setIsDefaultFolder(bool value);
     bool isDefaultFolder() const;
 
-    void setOwner( qlonglong id );
+    void setOwner(qlonglong id);
     qlonglong owner() const;
 
-    void setLastModified( const QString &timeStamp );
+    void setLastModified(const QString &timeStamp);
     QString lastModified() const;
 
-    void setUserPermissions( const UserPermissions &permissions );
+    void setUserPermissions(const UserPermissions &permissions);
     UserPermissions userPermissions() const;
 
-    void setGroupPermissions( const GroupPermissions &permissions );
+    void setGroupPermissions(const GroupPermissions &permissions);
     GroupPermissions groupPermissions() const;
 
-  private:
+private:
     ObjectStatus mObjectStatus;
     QString mTitle;
     Type mType;
@@ -200,5 +194,6 @@ class Folder
 };
 
 }
+Q_DECLARE_TYPEINFO( OXA::Folder, Q_MOVABLE_TYPE );
 
 #endif
